==> jindolf-src-2.9.4.zip: jindolf-src-2.9.4/src/jp/sourceforge/jindolf/GUIUtils.java <==
/*
 * GUI utilities
 *
 * Copyright(c) 2008 olyutorskii
 * $Id: GUIUtils.java 198 2008-09-26 09:23:39Z olyutorskii $
 */

package jp.sourceforge.jindolf;

import java.awt.Image;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.net.URL;
import java.util.logging.Level;
import javax.imageio.ImageIO;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;

/**
 * GUI関連のユーティリティクラス。
 */
public class GUIUtils{

    public static AffineTransform AFFINETX_IDENTITY = new AffineTransform();
    
    private static final String logoSource =
            "resources/image/logo.png";
    private static final String windowIconSource =
            "resources/image/winicon.png";
    private static Image logoImage;
    private static Icon logoIcon;
    private static Image windowIconImage;
    
    private static final RenderingHints normalHints;
    private static final RenderingHints qualityHints;
    private static final RenderingHints speedyHints;

    private static final Runnable taskNothing = new Runnable(){
        public void run(){}
    };
    
    static{
        normalHints = new RenderingHints(null);
        qualityHints = new RenderingHints(null);
        speedyHints = new RenderingHints(null);

        qualityHints.put(RenderingHints.KEY_ANTIALIASING,
                         RenderingHints.VALUE_ANTIALIAS_ON);
        speedyHints.put(RenderingHints.KEY_ANTIALIASING,
                        RenderingHints.VALUE_ANTIALIAS_OFF);

        qualityHints.put(RenderingHints.KEY_RENDERING,
                         RenderingHints.VALUE_RENDER_QUALITY);
        speedyHints.put(RenderingHints.KEY_RENDERING,
                        RenderingHints.VALUE_RENDER_SPEED);

        qualityHints.put(RenderingHints.KEY_DITHERING,
                         RenderingHints.VALUE_DITHER_ENABLE);
        speedyHints.put(RenderingHints.KEY_DITHERING,
                        RenderingHints.VALUE_DITHER_DISABLE);

        qualityHints.put(RenderingHints.KEY_TEXT_ANTIALIASING,
                         RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
        speedyHints.put(RenderingHints.KEY_TEXT_ANTIALIASING,
                        RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);

        qualityHints.put(RenderingHints.KEY_FRACTIONALMETRICS,
                         RenderingHints.VALUE_FRACTIONALMETRICS_ON);
        speedyHints.put(RenderingHints.KEY_FRACTIONALMETRICS,
                        RenderingHints.VALUE_FRACTIONALMETRICS_OFF);

        qualityHints.put(RenderingHints.KEY_INTERPOLATION,
                         RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        speedyHints.put(RenderingHints.KEY_INTERPOLATION,
                        RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR);

        qualityHints.put(RenderingHints.KEY_ALPHA_INTERPOLATION,
                         RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY);
        speedyHints.put(RenderingHints.KEY_ALPHA_INTERPOLATION,
                        RenderingHints.VALUE_ALPHA_INTERPOLATION_SPEED);

        qualityHints.put(RenderingHints.KEY_COLOR_RENDERING,
                         RenderingHints.VALUE_COLOR_RENDER_QUALITY);
        speedyHints.put(RenderingHints.KEY_COLOR_RENDERING,
                        RenderingHints.VALUE_COLOR_RENDER_SPEED);

        qualityHints.put(RenderingHints.KEY_STROKE_CONTROL,
                         RenderingHints.VALUE_STROKE_PURE);
        speedyHints.put(RenderingHints.KEY_STROKE_CONTROL,
                        RenderingHints.VALUE_STROKE_NORMALIZE);
    }

    /**
     * Jindolf デフォルトの描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getDefaultHints(){
        return normalHints;
//      return qualityHints;
//      return speedyHints;
    }

    /**
     * ノーマルな描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getNormalHints(){
        return normalHints;
    }

    /**
     * 描画品質優先の描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getQualityHints(){
        return qualityHints;
    }

    /**
     * 描画速度優先の描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getSpeedyHints(){
        return speedyHints;
    }

    /**
     * リソース名からイメージを取得する。
     * @param resource リソース名
     * @return イメージ
     * @throws java.io.IOException
     */
    public static Image loadImageFromResource(String resource)
            throws IOException{
        Image result;

        URL url = Jindolf.getResource(resource);
        result = ImageIO.read(url);
        
        return result;
    }
    
    /**
     * ロゴイメージを得る。
     * @return ロゴイメージ
     */
    public static Image getLogoImage(){
        if(logoImage != null){
            return logoImage;
        }

        Image image;
        try{
            image = loadImageFromResource(logoSource);
        }catch(IOException e){
            Jindolf.logger.log(Level.WARNING,
                               "ロゴイメージの取得に失敗しました",
                               e);
            image = new BufferedImage(100, 100, BufferedImage.TYPE_INT_ARGB);
            // TODO デカく "狼" とでも描くか？
        }
      
        logoImage = image;
        
        return logoImage;
    }
    
    /**
     * 各種ウィンドウのアイコンイメージを得る。
     * @return アイコンイメージ
     */
    public static Image getWindowIconImage(){
        if(windowIconImage != null){
            return windowIconImage;
        }

        Image image;
        try{
            image = loadImageFromResource(windowIconSource);
        }catch(IOException e){
            Jindolf.logger.log(Level.WARNING,
                               "アイコンイメージの取得に失敗しました",
                               e);
            image = getLogoImage();
        }

        windowIconImage = image;

        return windowIconImage;
    }

    /**
     * ロゴアイコンを得る。
     * @return ロゴアイコン
     */
    public static Icon getLogoIcon(){
        if(logoIcon != null){
            return logoIcon;
        }
        
        Icon icon = new ImageIcon(getLogoImage());
        
        logoIcon = icon;
        
        return logoIcon;
    }

    /**
     * AWTディスパッチイベント処理を促す。
     */
    public static void dispatchEmptyAWTEvent(){
        if(SwingUtilities.isEventDispatchThread()){
            return;
        }

        try{
            SwingUtilities.invokeAndWait(taskNothing);
        }catch(Exception e){
            // IGNORE
        }
        
        return;
    }

    /**
     * 矩形と点座標の相対関係を判定する。
     * ・矩形に点座標が含まれればSwingContants.CENTER
     * ・矩形の上辺より上に点座標が位置すればSwingContants.NORTH
     * ・矩形の下辺より下に点座標が位置すればSwingContants.SOUTH
     * ・矩形の上辺と下辺内に収まるが右辺からはみ出すときはSwingContants.EAST
     * ・矩形の上辺と下辺内に収まるが左辺からはみ出すときはSwingContants.WEST
     * @param rect 矩形
     * @param pt 点座標
     * @return 判定結果
     */
    public static int getDirection(Rectangle rect, Point pt){
        if(pt.y < rect.y){
            return SwingConstants.NORTH;
        }
        if(rect.y + rect.height <= pt.y){
            return SwingConstants.SOUTH;
        }
        if(pt.x < rect.x){
            return SwingConstants.EAST;
        }
        if(rect.x + rect.width <= pt.x){
            return SwingConstants.WEST;
        }
        return SwingConstants.CENTER;
    }
    
    /**
     * hidden constructor
     */
    private GUIUtils(){
        super();
        return;
    }
}

==> jindolf-src-2.12.2.zip: jindolf-src-2.12.2/src/jp/sourceforge/jindolf/GUIUtils.java <==
/*
 * GUI utilities
 *
 * Copyright(c) 2008 olyutorskii
 * $Id: GUIUtils.java 250 2008-10-11 18:05:25Z olyutorskii $
 */

package jp.sourceforge.jindolf;

import java.awt.Dialog;
import java.awt.Frame;
import java.awt.Image;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.Toolkit;
import java.awt.Window;
import java.awt.geom.AffineTransform;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.net.URL;
import java.util.logging.Level;
import javax.imageio.ImageIO;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.SwingConstants;
import javax.swing.SwingUtilities;

/**
 * GUI関連のユーティリティクラス。
 */
public class GUIUtils{

    public static AffineTransform AFFINETX_IDENTITY = new AffineTransform();

    private static final String logoSource =
            "resources/image/logo.png";
    private static final String windowIconSource =
            "resources/image/winicon.png";
    private static Image logoImage;
    private static Icon logoIcon;
    private static Image windowIconImage;

    private static final RenderingHints normalHints;
    private static final RenderingHints qualityHints;
    private static final RenderingHints speedyHints;

    private static final Runnable taskNothing = new Runnable(){
        public void run(){}
    };

    static{
        normalHints = new RenderingHints(null);
        qualityHints = new RenderingHints(null);
        speedyHints = new RenderingHints(null);

        qualityHints.put(RenderingHints.KEY_ANTIALIASING,
                         RenderingHints.VALUE_ANTIALIAS_ON);
        speedyHints.put(RenderingHints.KEY_ANTIALIASING,
                        RenderingHints.VALUE_ANTIALIAS_OFF);

        qualityHints.put(RenderingHints.KEY_RENDERING,
                         RenderingHints.VALUE_RENDER_QUALITY);
        speedyHints.put(RenderingHints.KEY_RENDERING,
                        RenderingHints.VALUE_RENDER_SPEED);

        qualityHints.put(RenderingHints.KEY_DITHERING,
                         RenderingHints.VALUE_DITHER_ENABLE);
        speedyHints.put(RenderingHints.KEY_DITHERING,
                        RenderingHints.VALUE_DITHER_DISABLE);

        qualityHints.put(RenderingHints.KEY_TEXT_ANTIALIASING,
                         RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
        speedyHints.put(RenderingHints.KEY_TEXT_ANTIALIASING,
                        RenderingHints.VALUE_TEXT_ANTIALIAS_OFF);

        qualityHints.put(RenderingHints.KEY_FRACTIONALMETRICS,
                         RenderingHints.VALUE_FRACTIONALMETRICS_ON);
        speedyHints.put(RenderingHints.KEY_FRACTIONALMETRICS,
                        RenderingHints.VALUE_FRACTIONALMETRICS_OFF);

        qualityHints.put(RenderingHints.KEY_INTERPOLATION,
                         RenderingHints.VALUE_INTERPOLATION_BICUBIC);
        speedyHints.put(RenderingHints.KEY_INTERPOLATION,
                        RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR);

        qualityHints.put(RenderingHints.KEY_ALPHA_INTERPOLATION,
                         RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY);
        speedyHints.put(RenderingHints.KEY_ALPHA_INTERPOLATION,
                        RenderingHints.VALUE_ALPHA_INTERPOLATION_SPEED);

        qualityHints.put(RenderingHints.KEY_COLOR_RENDERING,
                         RenderingHints.VALUE_COLOR_RENDER_QUALITY);
        speedyHints.put(RenderingHints.KEY_COLOR_RENDERING,
                        RenderingHints.VALUE_COLOR_RENDER_SPEED);

        qualityHints.put(RenderingHints.KEY_STROKE_CONTROL,
                         RenderingHints.VALUE_STROKE_PURE);
        speedyHints.put(RenderingHints.KEY_STROKE_CONTROL,
                        RenderingHints.VALUE_STROKE_NORMALIZE);
    }

    /**
     * Jindolf デフォルトの描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getDefaultHints(){
        return normalHints;
//      return qualityHints;
//      return speedyHints;
    }

    /**
     * ノーマルな描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getNormalHints(){
        return normalHints;
    }

    /**
     * 描画品質優先の描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getQualityHints(){
        return qualityHints;
    }

    /**
     * 描画速度優先の描画ヒントを返す。
     * @return 描画ヒント
     */
    public static RenderingHints getSpeedyHints(){
        return speedyHints;
    }

    /**
     * リソース名からイメージを取得する。
     * @param resource リソース名
     * @return イメージ
     * @throws java.io.IOException
     */
    public static Image loadImageFromResource(String resource)
            throws IOException{
        Image result;

        URL url = Jindolf.getResource(resource);
        result = ImageIO.read(url);

        return result;
    }

    /**
     * ロゴイメージを得る。
     * @return ロゴイメージ
     */
    public static Image getLogoImage(){
        if(logoImage != null){
            return logoImage;
        }

        Image image;
        try{
            image = loadImageFromResource(logoSource);
        }catch(IOException e){
            Jindolf.logger.log(Level.WARNING,
                               "ロゴイメージの取得に失敗しました",
                               e);
            image = new BufferedImage(100, 100, BufferedImage.TYPE_INT_ARGB);
            // TODO デカく "狼" とでも描くか？
        }

        logoImage = image;

        return logoImage;
    }

    /**
     * 各種ウィンドウのアイコンイメージを得る。
     * @return アイコンイメージ
     */
    public static Image getWindowIconImage(){
        if(windowIconImage != null){
            return windowIconImage;
        }

        Image image;
        try{
            image = loadImageFromResource(windowIconSource);
        }catch(IOException e){
            Jindolf.logger.log(Level.WARNING,
                               "アイコンイメージの取得に失敗しました",
                               e);
            image = getLogoImage();
        }

        windowIconImage = image;

        return windowIconImage;
    }

    /**
     * ロゴアイコンを得る。
     * @return ロゴアイコン
     */
    public static Icon getLogoIcon(){
        if(logoIcon != null){
            return logoIcon;
        }

        Icon icon = new ImageIcon(getLogoImage());

        logoIcon = icon;

        return logoIcon;
    }

    /**
     * AWTディスパッチイベント処理を促す。
     */
    public static void dispatchEmptyAWTEvent(){
        if(SwingUtilities.isEventDispatchThread()){
            return;
        }

        try{
            SwingUtilities.invokeAndWait(taskNothing);
        }catch(Exception e){
            // IGNORE
        }

        return;
    }

    /**
     * 矩形と点座標の相対関係を判定する。
     * ・矩形に点座標が含まれればSwingContants.CENTER
     * ・矩形の上辺より上に点座標が位置すればSwingContants.NORTH
     * ・矩形の下辺より下に点座標が位置すればSwingContants.SOUTH
     * ・矩形の上辺と下辺内に収まるが右辺からはみ出すときはSwingContants.EAST
     * ・矩形の上辺と下辺内に収まるが左辺からはみ出すときはSwingContants.WEST
     * @param rect 矩形
     * @param pt 点座標
     * @return 判定結果
     */
    public static int getDirection(Rectangle rect, Point pt){
        if(pt.y < rect.y){
            return SwingConstants.NORTH;
        }
        if(rect.y + rect.height <= pt.y){
            return SwingConstants.SOUTH;
        }
        if(pt.x < rect.x){
            return SwingConstants.EAST;
        }
        if(rect.x + rect.width <= pt.x){
            return SwingConstants.WEST;
        }
        return SwingConstants.CENTER;
    }

    /**
     * ウィンドウ属性を設定する。
     * @param window ウィンドウ
     * @param isResizable リサイズ可ならtrue
     * @param isDynamic リサイズに伴う再描画ならtrue
     * @param isAutoLocation 自動位置決め機構を使うならtrue
     */
    public static void modifyWindowAttributes(Window window,
                                                 boolean isResizable,
                                                 boolean isDynamic,
                                                 boolean isAutoLocation){
        Toolkit kit = window.getToolkit();
        kit.setDynamicLayout(isDynamic);
        
        window.setLocationByPlatform(isAutoLocation);
        
        if(window instanceof Frame){
            Frame frame = (Frame) window;
            frame.setIconImage(getWindowIconImage());
            frame.setResizable(isResizable);
        }else if(window instanceof Dialog){
            Dialog dialog = (Dialog) window;
            dialog.setResizable(isResizable);
        }
        
        return;
    }
    
    /**
     * hidden constructor
     */
    private GUIUtils(){
        super();
        return;
    }
}
